@@ -7,6 +7,9 @@ validate_X <- function(X, allow.na = FALSE) {
       "`matrix`, `data.frame`"
     ))
   }
+  if (any(0 %in% dim(X))) {
+    stop("Feature matrix X must have non-zero dimensions.")
+  }
 
   if (!is.numeric(as.matrix(X))) {
     stop(paste(
@@ -310,3 +313,12 @@ validate_sandwich <- function(subset.weights) {
     }
   }
 }
+
+get_legacy_seed <- function() {
+  opt <- getOption("grf.legacy.seed", default = FALSE)
+  if (!is.logical(opt) || length(opt) != 1) {
+    stop("grf option `grf.legacy.seed` should be either TRUE or FALSE.")
+  }
+
+  opt
+}
