@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -48,7 +50,8 @@ Rcpp::List instrumental_train(const Rcpp::NumericMatrix& train_matrix,
                               unsigned int samples_per_cluster,
                               bool compute_oob_predictions,
                               unsigned int num_threads,
-                              unsigned int seed) {
+                              unsigned int seed,
+                              bool legacy_seed) {
   ForestTrainer trainer = instrumental_trainer(reduced_form_weight, stabilize_splits);
 
   Data data = RcppUtilities::convert_data(train_matrix);
@@ -60,7 +63,7 @@ Rcpp::List instrumental_train(const Rcpp::NumericMatrix& train_matrix,
   }
 
   ForestOptions options(num_trees, ci_group_size, sample_fraction, mtry, min_node_size, honesty,
-      honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, clusters, samples_per_cluster);
+      honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, legacy_seed, clusters, samples_per_cluster);
   Forest forest = trainer.train(data, options);
 
   std::vector<Prediction> predictions;
