@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -14,7 +16,7 @@
   You should have received a copy of the GNU General Public License
   along with grf. If not, see <http://www.gnu.org/licenses/>.
  #-------------------------------------------------------------------------------*/
- 
+
 #include <Rcpp.h>
 #include <vector>
 
@@ -44,7 +46,8 @@ Rcpp::List quantile_train(std::vector<double> quantiles,
                           unsigned int samples_per_cluster,
                           bool compute_oob_predictions,
                           int num_threads,
-                          unsigned int seed) {
+                          unsigned int seed,
+                          bool legacy_seed) {
   ForestTrainer trainer = regression_splitting
       ? regression_trainer()
       : quantile_trainer(quantiles);
@@ -53,7 +56,7 @@ Rcpp::List quantile_train(std::vector<double> quantiles,
   data.set_outcome_index(outcome_index);
 
   ForestOptions options(num_trees, ci_group_size, sample_fraction, mtry, min_node_size, honesty,
-      honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, clusters, samples_per_cluster);
+      honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, legacy_seed, clusters, samples_per_cluster);
   Forest forest = trainer.train(data, options);
 
   std::vector<Prediction> predictions;
