@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -45,7 +47,8 @@ Rcpp::List survival_train(const Rcpp::NumericMatrix& train_matrix,
                           bool compute_oob_predictions,
                           int prediction_type,
                           unsigned int num_threads,
-                          unsigned int seed) {
+                          unsigned int seed,
+                          bool legacy_seed) {
   ForestTrainer trainer = survival_trainer();
 
   Data data = RcppUtilities::convert_data(train_matrix);
@@ -58,7 +61,7 @@ Rcpp::List survival_train(const Rcpp::NumericMatrix& train_matrix,
   size_t ci_group_size = 1;
   size_t imbalance_penalty = 0;
   ForestOptions options(num_trees, ci_group_size, sample_fraction, mtry, min_node_size, honesty,
-      honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, clusters, samples_per_cluster);
+      honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, legacy_seed, clusters, samples_per_cluster);
   Forest forest = trainer.train(data, options);
 
   std::vector<Prediction> predictions;
