@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -34,11 +36,12 @@ public:
                 uint min_node_size,
                 bool honesty,
                 double honesty_fraction,
-                bool prune_empty_leaves,
+                bool honesty_prune_leaves,
                 double alpha,
                 double imbalance_penalty,
                 uint num_threads,
                 uint random_seed,
+                bool legacy_seed,
                 const std::vector<size_t>& sample_clusters,
                 uint samples_per_cluster);
 
@@ -53,6 +56,8 @@ public:
 
   uint get_num_threads() const;
   uint get_random_seed() const;
+  // Toggle between seed and num_threads dependence to reproduce behavior prior to grf 2.4.0.
+  bool get_legacy_seed() const;
 
 private:
   uint num_trees;
@@ -64,6 +69,7 @@ private:
 
   uint num_threads;
   uint random_seed;
+  bool legacy_seed;
 };
 
 } // namespace grf
