@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -18,7 +20,6 @@
 #ifndef GRF_REGRESSIONPREDICTIONSTRATEGY_H
 #define GRF_REGRESSIONPREDICTIONSTRATEGY_H
 
-#include "commons/DefaultData.h"
 #include "commons/Data.h"
 #include "prediction/OptimizedPredictionStrategy.h"
 #include "prediction/PredictionValues.h"
@@ -50,6 +51,7 @@ public:
 
 private:
   static const std::size_t OUTCOME;
+  static const std::size_t WEIGHT;
   ObjectiveBayesDebiaser bayes_debiaser;
 };
 
