@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -30,7 +32,7 @@ public:
   bool relabel(
       const std::vector<size_t>& samples,
       const Data& data,
-      std::vector<double>& responses_by_sample) const;
+      Eigen::ArrayXXd& responses_by_sample) const;
 private:
   std::vector<double> quantiles;
 };
