@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -18,7 +20,7 @@
 #ifndef GRF_REGRESSIONSPLITTINGRULE_H
 #define GRF_REGRESSIONSPLITTINGRULE_H
 
-#include "commons/DefaultData.h"
+#include "commons/Data.h"
 #include "splitting/SplittingRule.h"
 #include "tree/Tree.h"
 
@@ -35,7 +37,7 @@ public:
   bool find_best_split(const Data& data,
                        size_t node,
                        const std::vector<size_t>& possible_split_vars,
-                       const std::vector<double>& responses_by_sample,
+                       const Eigen::ArrayXXd& responses_by_sample,
                        const std::vector<std::vector<size_t>>& samples,
                        std::vector<size_t>& split_vars,
                        std::vector<double>& split_values,
@@ -53,7 +55,7 @@ private:
                              size_t& best_var,
                              double& best_decrease,
                              bool& best_send_missing_left,
-                             const std::vector<double>& responses_by_sample,
+                             const Eigen::ArrayXXd& responses_by_sample,
                              const std::vector<std::vector<size_t>>& samples);
 
   size_t* counter;
