@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -18,7 +20,7 @@
 #include <algorithm>
 #include <memory>
 
-#include "commons/DefaultData.h"
+#include "commons/Data.h"
 #include "tree/TreeTrainer.h"
 
 namespace grf {
@@ -63,7 +65,7 @@ std::unique_ptr<Tree> TreeTrainer::train(const Data& data,
 
   size_t num_open_nodes = 1;
   size_t i = 0;
-  std::vector<double> responses_by_sample(data.get_num_rows());
+  Eigen::ArrayXXd responses_by_sample(data.get_num_rows(), relabeling_strategy->get_response_length());
   while (num_open_nodes > 0) {
     bool is_leaf_node = split_node(i,
                                    data,
@@ -148,7 +150,7 @@ bool TreeTrainer::split_node(size_t node,
                              std::vector<size_t>& split_vars,
                              std::vector<double>& split_values,
                              std::vector<bool>& send_missing_left,
-                             std::vector<double>& responses_by_sample,
+                             Eigen::ArrayXXd& responses_by_sample,
                              const TreeOptions& options) const {
 
   std::vector<size_t> possible_split_vars;
@@ -207,7 +209,7 @@ bool TreeTrainer::split_node_internal(size_t node,
                                       std::vector<size_t>& split_vars,
                                       std::vector<double>& split_values,
                                       std::vector<bool>& send_missing_left,
-                                      std::vector<double>& responses_by_sample,
+                                      Eigen::ArrayXXd& responses_by_sample,
                                       uint min_node_size) const {
   // Check node size, stop if maximum reached
   if (samples[node].size() <= min_node_size) {
