@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -20,7 +22,8 @@
 
 #include <memory>
 
-#include "commons/DefaultData.h"
+#include "Eigen/Dense"
+#include "commons/Data.h"
 #include "prediction/OptimizedPredictionStrategy.h"
 #include "relabeling/RelabelingStrategy.h"
 #include "sampling/RandomSampler.h"
@@ -67,7 +70,7 @@ private:
                   std::vector<size_t>& split_vars,
                   std::vector<double>& split_values,
                   std::vector<bool>& send_missing_left,
-                  std::vector<double>& responses_by_sample,
+                  Eigen::ArrayXXd& responses_by_sample,
                   const TreeOptions& tree_options) const;
 
   bool split_node_internal(size_t node,
@@ -78,7 +81,7 @@ private:
                            std::vector<size_t>& split_vars,
                            std::vector<double>& split_values,
                            std::vector<bool>& send_missing_left,
-                           std::vector<double>& responses_by_sample,
+                           Eigen::ArrayXXd& responses_by_sample,
                            uint min_node_size) const ;
 
   std::set<size_t> disallowed_split_variables;
